<?php

namespace Objects\Object\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Objects\Object\Http\Requests\BtObjectRequest;
use Objects\Object\Interfaces\BtObjectRepositoryInterface;
use Objects\Object\Models\BtObject;
use Objects\Object\Forms\BtObject as Form;

/**
 * APIController  class for bt_object.
 */
class BtObjectAPIController extends BaseController
{

    /**
     * Initialize bt_object resource controller.
     *
     * @param type BtObjectRepositoryInterface $bt_object
     *
     * @return null
     */
    public function __construct(BtObjectRepositoryInterface $bt_object)
    {
        parent::__construct();
        $this->repository = $bt_object;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Objects\Object\Repositories\Criteria\BtObjectResourceCriteria::class);
    }

    /**
     * Display a list of bt_object.
     *
     * @return Response
     */
    public function index(BtObjectRequest $request)
    {
        return $this->repository
            ->setPresenter(\Objects\Object\Repositories\Presenter\BtObjectPresenter::class)
            ->paginate();
    }

    /**
     * Display bt_object.
     *
     * @param Request $request
     * @param Model   $bt_object
     *
     * @return Response
     */
    public function show(BtObjectRequest $request, BtObject $bt_object)
    {
        return $bt_object->setPresenter(\Objects\Object\Repositories\Presenter\BtObjectListPresenter::class);
        ;
    }

    /**
     * Create new bt_object.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BtObjectRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('object::bt_object.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('object/bt_object/' . $bt_object->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('object/bt_object');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the bt_object.
     *
     * @param Request $request
     * @param Model   $bt_object
     *
     * @return Response
     */
    public function update(BtObjectRequest $request, BtObject $bt_object)
    {
        try {
            $data = $request->all();

            $bt_object->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('object::bt_object.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('object/bt_object/' . $bt_object->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('object/bt_object/' . $bt_object->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the bt_object.
     *
     * @param Model   $bt_object
     *
     * @return Response
     */
    public function destroy(BtObjectRequest $request, BtObject $bt_object)
    {
        try {
            $bt_object->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('object::bt_object.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('object/bt_object/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('object/bt_object/' . $bt_object->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
