<?php

namespace Objects\Object\Policies;

use Litepie\User\Contracts\UserPolicy;
use Objects\Object\Models\BtObject;

class BtObjectPolicy
{

    /**
     * Determine if the given user can view the bt_object.
     *
     * @param UserPolicy $user
     * @param BtObject $bt_object
     *
     * @return bool
     */
    public function view(UserPolicy $user, BtObject $bt_object)
    {
        if ($user->canDo('object.bt_object.view') && $user->isAdmin()) {
            return true;
        }

        return $bt_object->user_id == user_id() && $bt_object->user_type == user_type();
    }

    /**
     * Determine if the given user can create a bt_object.
     *
     * @param UserPolicy $user
     * @param BtObject $bt_object
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('object.bt_object.create');
    }

    /**
     * Determine if the given user can update the given bt_object.
     *
     * @param UserPolicy $user
     * @param BtObject $bt_object
     *
     * @return bool
     */
    public function update(UserPolicy $user, BtObject $bt_object)
    {
        if ($user->canDo('object.bt_object.edit') && $user->isAdmin()) {
            return true;
        }

        return $bt_object->user_id == user_id() && $bt_object->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given bt_object.
     *
     * @param UserPolicy $user
     * @param BtObject $bt_object
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BtObject $bt_object)
    {
        return $bt_object->user_id == user_id() && $bt_object->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given bt_object.
     *
     * @param UserPolicy $user
     * @param BtObject $bt_object
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BtObject $bt_object)
    {
        if ($user->canDo('object.bt_object.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given bt_object.
     *
     * @param UserPolicy $user
     * @param BtObject $bt_object
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BtObject $bt_object)
    {
        if ($user->canDo('object.bt_object.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
